import React, { useImperativeHandle, useRef, useState } from 'react';
import { View, UIManager, findNodeHandle, Text, Platform, StyleSheet } from 'react-native';
import { VisionSdkView } from './VisionSdkViewManager';
var ScanMode; // enum AutoMode  ["auto", "manual"]
(function (ScanMode) {
  ScanMode["OCR"] = "ocr";
  ScanMode["BARCODE"] = "barcode";
  ScanMode["QRCODE"] = "qrcode";
})(ScanMode || (ScanMode = {}));
const Camera = _ref => {
  let {
    children,
    refProp,
    BarCodeScanHandler = _e => {},
    OCRScanHandler = _e => {},
    OnDetectedHandler = _e => {},
    onError = _e => {}
  } = _ref;
  const defaultScanMode = ScanMode.OCR;
  const [mode, setMode] = useState(defaultScanMode);
  // const [captureMode, setCaptureMode] = useState<String>('auto');
  // const [apiKey, setAPIKey] = useState < String > ('key_stag_7da7b5e917tq2eCckhc5QnTr1SfpvFGjwbTfpu1SQYy242xPjBz2mk3hbtzN6eB85MftxVw1zj5K5XBF')

  const VisionSDKViewRef = useRef(null);
  useImperativeHandle(refProp, () => ({
    cameraCaptureHandler: () => {
      onPressCaptures();
    },
    changeModeHandler: input => {
      onChangeMode(input);
    }
  }));
  const onPressCaptures = () => {
    console.log('Image Captured');
    UIManager.dispatchViewManagerCommand(findNodeHandle(VisionSDKViewRef.current), UIManager.hasViewManagerConfig('VisionSDKView') && UIManager.getViewManagerConfig('VisionSDKView').Commands.captureImage || 0, []);
  };
  const onChangeMode = input => {
    setMode(input);
  };
  return Platform.OS === 'ios' ? /*#__PURE__*/React.createElement(VisionSdkView, {
    style: styles.flex,
    onBarcodeScanSuccess: BarCodeScanHandler,
    onOCRDataReceived: OCRScanHandler,
    onDetected: OnDetectedHandler
    // onDetected={onDetected}
    // OnDetectedHandler={OnDetectedHandler}
    // onOCRDataReceived={({ nativeEvent }) =>
    //   console.log('onOCRDataReceived', nativeEvent)
    // }
    // onBarcodeScanSuccess={({ nativeEvent }) =>
    //   console.log('onBarcodeScanSuccess', nativeEvent)
    // }
    ,
    mode: mode,
    apiKey: 'key_stag_7da7b5e917tq2eCckhc5QnTr1SfpvFGjwbTfpu1SQYy242xPjBz2mk3hbtzN6eB85MftxVw1zj5K5XBF',
    captureMode: 'auto',
    onError: onError
    // onDetected={onDetected}
    ,
    ref: VisionSDKViewRef
  }, children) : /*#__PURE__*/React.createElement(View, {
    style: styles.flex
  }, /*#__PURE__*/React.createElement(Text, null, "NOT IMPLEMENTED FOR ANDROID YET."));
};
export default Camera;

// type ActionButtonType = {
//   text?: string;
//   onPress?: () => void | undefined;
//   isSeleted?: boolean | undefined;
//   icon?: string | undefined;
//   style?: any;
//   textColor?: string | undefined | null | any;
// };
// const ActionButton = ({
//   text,
//   onPress,
//   isSeleted,
//   icon,
//   style,
//   textColor,
// }: ActionButtonType) => {
//   return (
//     <TouchableOpacity style={[style && style]} onPress={onPress}>
//       <Text
//         style={[
//           isSeleted ? styles.buttonText : styles.unbuttonText,
//           textColor && { color: textColor },
//         ]}
//       >
//         {text}
//       </Text>
//       {icon ?? <Image source={icon} />}
//     </TouchableOpacity>
//   );
// };

const styles = StyleSheet.create({
  flex: {
    flex: 1
  },
  row: {
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'space-between'
  },
  buttonText: {
    fontSize: 15,
    color: 'yellow'
  },
  unbuttonText: {
    fontSize: 15,
    color: 'white'
  },
  zoomBlock: {
    paddingHorizontal: 5,
    borderRadius: 30,
    height: 40,
    flexDirection: 'row',
    backgroundColor: '#00000050',
    justifyContent: 'space-between'
  },
  iconStyle: {
    width: 55,
    height: 55,
    bottom: 8
  },
  autoManualBlock: {
    borderRadius: 4,
    paddingHorizontal: 2,
    height: 40,
    alignItems: 'center',
    flexDirection: 'row',
    backgroundColor: 'grey',
    justifyContent: 'space-between'
  },
  autoManualButton: {
    backgroundColor: '#fff',
    width: 80,
    borderRadius: 4,
    height: 30,
    marginHorizontal: 4,
    paddingHorizontal: 10,
    alignItems: 'center',
    justifyContent: 'center'
  },
  unautoManualButton: {
    backgroundColor: 'grey',
    width: 80,
    borderRadius: 4,
    height: 30,
    marginHorizontal: 4,
    paddingHorizontal: 10,
    alignItems: 'center',
    justifyContent: 'center'
  },
  circle: {
    width: 30,
    height: 30,
    borderRadius: 40,
    marginVertical: 5,
    marginHorizontal: 5,
    backgroundColor: '#00000050'
  },
  childrenContainer: {
    paddingTop: 20,
    justifyContent: 'space-between',
    position: 'absolute',
    top: 0,
    left: 0,
    height: '100%',
    width: '100%'
  }
});
//# sourceMappingURL=index.js.map